@@ -1,16 +1,18 @@
 package XAS::Apps::Test::Echo::Server;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
-use POE;
-use Try::Tiny;
-use XAS::System;
 use XAS::Lib::Net::Server;
-use XAS::Lib::Daemon::Logger;
-
 use XAS::Class
-  version => $VERSION,
-  base    => 'XAS::Lib::App::Daemon::POE',
+  debug     => 0,
+  version   => $VERSION,
+  base      => 'XAS::Lib::App::Service',
+  accessors => 'port address',
+  vars => {
+    SERVICE_NAME         => 'XAS_Echo_Server',
+    SERVICE_DISPLAY_NAME => 'XAS Echo Server',
+    SERVICE_DESCRIPTION  => 'This is a test Perl service',
+  }
 ;
 
 # ----------------------------------------------------------------------
@@ -20,25 +22,31 @@ use XAS::Class
 sub main {
     my $self = shift;
 
-    my ($logger, $server);
-
-    $logger = XAS::Lib::Daemon::Logger->new(
-        -alias  => 'logger',
-        -logger => $self->logger
-    );
-
-    $server = XAS::Lib::Net::Server->new(
+    my $server = XAS::Lib::Net::Server->new(
         -alias   => 'echo',
-        -logger  => 'logger',
         -port    => $self->port,
         -address => $self->address,
     );
 
-    $self->log('info', 'Starting up');
+    $self->log->info('Starting up');
 
-    $poe_kernel->run();
+    $self->service->register('echo');
+    $self->service->run();
 
-    $self->log('info', 'Shutting down');
+    $self->log->info('Shutting down');
+
+}
+
+sub options {
+    my $self = shift;
+
+    $self->{port}    = '9505';
+    $self->{address} = '127.0.0.1';
+
+    return {
+        'port=s'    => \$self->{port},
+        'address=s' => \$self->{address},
+     };
 
 }
 
@@ -60,10 +68,6 @@ XAS::Apps::Test::Echo::Server - This module is an 'echo' server
 
  my $app = XAS::Apps::Test::Echo::Server->new(
      -throws => 'something',
-     -options => [
-         { 'port=s',    '' },
-         { 'address=s', '' },
-     ]
  );
 
  exit $app->run();
@@ -72,22 +76,21 @@ XAS::Apps::Test::Echo::Server - This module is an 'echo' server
 
 This module will 'echo' received messages back to the sender.
 
-=head1 METHODS
+=head1 CONFIGURATION
 
-=head2 new
+There is no additional configuration.
 
-This method will initialize the module and accepts these parameters.
+=head1 OPTIONS
 
-=over 4
+This module provides these additonal cli options.
 
-=item B<-options>
+=head2 --port
 
-This specifies three options that may be on the command line. They are
+The port the server will listen on. Defaults to '9505'.
 
-    port    - the port to listen on.
-    address - the address to bind too.
+=head2 --address
 
-=back
+The address the server will attache too. Defaults to '127.0.0.1';
 
 =head1 SEE ALSO
 
@@ -107,8 +110,8 @@ Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 Copyright (C) 2012 by Kevin L. Esteb
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.8 or,
-at your option, any later version of Perl 5 you may have available.
+This is free software; you can redistribute it and/or modify it under
+the terms of the Artistic License 2.0. For details, see the full text
+of the license at http://www.perlfoundation.org/artistic_license_2_0.
 
 =cut
