@@ -1,6 +1,6 @@
 package XAS::Lib::Modules::Alerts;
 
-our $VERSION = '0.04';
+our $VERSION = '0.06';
 
 use DateTime;
 use Try::Tiny;
@@ -10,10 +10,9 @@ use XAS::Class
   debug      => 0,
   version    => $VERSION,
   base       => 'XAS::Singleton',
-  constants  => ':alerts',
   accessors  => 'spooler',
   codec      => 'JSON',
-  utils      => 'dt2db',
+  utils      => ':validation',
   filesystem => 'Dir'
 ;
 
@@ -23,25 +22,20 @@ use XAS::Class
 
 sub send {
     my $self = shift;
-    my $p = $self->validate_params(\@_, { 
-        -message  => 1,
-        -process  => 1,
-        -facility => { optional => 1, default => 'systems', regex => ALERT_FACILITY },
-        -priority => { optional => 1, default => 'low', regex => ALERT_PRIORITY }, 
-    });
+    my ($message) = validate_params(\@_, [1]);
 
     my $dt = DateTime->now(time_zone => 'local');
 
     my $data = {
         hostname => $self->env->host,
-        datetime => dt2db($dt),
-        process  => $p->{'process'},
+        datetime => $dt->strftime('%Y-%m-%dT%H:%M:%S.%3N%z'),
+        process  => $self->env->script,
         pid      => $$,
         tid      => 0,
-        msgid    => 0,
-        priority => $p->{'priority'},
-        facility => $p->{'facility'},
-        message  => $p->{'message'},
+        msgnum   => 0,
+        priority => $self->env->priority,
+        facility => $self->env->facility,
+        message  => $message,
     };
 
     my $json = encode($data);
@@ -59,9 +53,10 @@ sub init {
 
     my $self = $class->SUPER::init(@_);
 
-    $self->{spooler} = XAS::Factory->module('spooler', {
+    $self->{'spooler'} = XAS::Factory->module('spooler', {
         -directory => Dir($self->env->spool, 'alerts'),
-        -mask      => 0777
+        -lock      => Dir($self->env->spool, 'alerts', 'locked')->path,
+        -mask      => 0777,
     });
 
     return $self;
@@ -84,11 +79,7 @@ Your program can use this module in the following fashion:
 
  my $alert = XAS::Lib::Modules::Alerts->new();
 
- $alert->send(
-     -priority => 'high',
-     -facility => 'huston',
-     -message  => 'There is a problem'
- );
+ $alert->send('There is a problem');
 
 =head1 DESCRIPTION
 
@@ -102,23 +93,15 @@ and will auto-load when invoked.
 
 This method initializes the module.
 
-=head2 send
+=head2 send($message)
 
 This method will send an alert. It takes the following named parameters:
 
 =over 4
 
-=item B<-priority>
+=item B<$message>
 
-The notification level, 'high','medium','low'. Default 'low'.
-
-=item B<-facility>
-
-The notification facility, 'systems', 'dba', etc.  Default 'systems'.
-
-=item B<-message>
-
-The message text for the message
+The message to send.
 
 =back
 
@@ -136,7 +119,7 @@ Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014 Kevin L. Esteb
+Copyright (c) 2012-2015 Kevin L. Esteb
 
 This is free software; you can redistribute it and/or modify it under
 the terms of the Artistic License 2.0. For details, see the full text
