@@ -10,10 +10,10 @@ use XAS::Class
   debug      => 0,
   version    => $VERSION,
   base       => 'XAS::Singleton',
-  utils      => 'dir_walk',
-  constants  => ':logging', 
+  utils      => ':validation dir_walk',
+  constants  => ':logging :alerts STOMP_LEVELS',
   filesystem => 'File Dir Path Cwd',
-  accessors  => 'path host domain username script commandline',
+  accessors  => 'path host domain username commandline',
   mutators   => 'mqserver mqport mxserver mxport mxtimeout msgs alerts xdebug',
 ;
 
@@ -23,56 +23,104 @@ use XAS::Class
 
 sub mxmailer {
     my $self = shift;
-    my ($mailer) = $self->validate_params(\@_, [
+    my ($mailer) = validate_params(\@_, [
         { optional => 1, default => undef, regex => qr/sendmail|smtp/ }
     ]);
 
-    $self->{mxmailer} = $mailer if (defined($mailer));
+    $self->{'mxmailer'} = $mailer if (defined($mailer));
 
-    return $self->{mxmailer};
+    return $self->{'mxmailer'};
 
 }
 
 sub mqlevel {
     my $self = shift;
-    my ($level) = $self->validate_params(\@_, [
-        { optional => 1, default => undef, regex => qr/(1\.0|1\.1|1\.2)/ },
+    my ($level) = validate_params(\@_, [
+        { optional => 1, default => undef, regex => STOMP_LEVELS },
     ]);
 
-    $self->{mqlevel} = $level if (defined($level));
+    $self->{'mqlevel'} = $level if (defined($level));
 
-    return $self->{mqlevel};
+    return $self->{'mqlevel'};
 
 }
 
 sub log_type {
     my $self = shift;
-    my ($type) = $self->validate_params(\@_, [
+    my ($type) = validate_params(\@_, [
         { optional => 1, default => undef, regex => LOG_TYPES }
     ]);
 
-    $self->{log_type} = $type if (defined($type));
+    $self->{'log_type'} = $type if (defined($type));
 
-    return $self->{log_type};
+    return $self->{'log_type'};
 
 }
 
 sub log_facility {
     my $self = shift;
-    my ($type) = $self->validate_params(\@_, [
+    my ($type) = validate_params(\@_, [
         { optional => 1, default => undef, regex => LOG_FACILITY }
     ]);
 
-    $self->{log_facility} = $type if (defined($type));
+    $self->{'log_facility'} = $type if (defined($type));
 
-    return $self->{log_facility};
+    return $self->{'log_facility'};
 
 }
+
+sub throws {
+    my $self = shift;
+    my ($throws) = validate_params(\@_, [
+        { optional => 1, default => undef }
+    ]);
+
+    $self->{'throws'} = $throws if (defined($throws));
+
+    return $self->{'throws'};
+
+}
+
+sub priority {
+    my $self = shift;
+    my ($level) = validate_params(\@_, [
+        { optional => 1, default => undef, regex => ALERT_PRIORITY }
+    ]);
+
+    $self->{'priority'} = $level if (defined($level));
+
+    return $self->{'priority'};
+
+}
+
+sub facility {
+    my $self = shift;
+    my ($level) = validate_params(\@_, [
+        { optional => 1, default => undef, regex => ALERT_FACILITY }
+    ]);
+
+    $self->{'facility'} = $level if (defined($level));
+
+    return $self->{'facility'};
+
+}
+
+sub script {
+    my $self = shift;
+    my ($script) = validate_params(\@_, [
+        { optional => 1, default => undef }
+    ]);
     
+    $self->{'script'} = $script if (defined($script));
+
+    return $self->{'script'};
+
+}
+
 sub get_msgs {
     my $self = shift;
 
-    return $self->class->any_var('MESSAGES');
+    return $self->class->var('MESSAGES');
 
 }
 
@@ -83,7 +131,7 @@ sub get_msgs {
 sub _load_msgs {
     my $self = shift;
 
-    my $messages = $self->class->hash_vars('MESSAGES');
+    my $messages = $self->class->any_var('MESSAGES');
 
     foreach my $path (@INC) {
 
@@ -137,43 +185,54 @@ sub init {
 
     # set some defaults
 
-    $self->{alerts} = 1;
-    $self->{xdebug} = 0;
-    $self->{mxtimeout} = 60;
-    $self->{script} = $script;
-    $self->{path} = $ENV{'PATH'};
-    $self->{commandline} = $commandline;
+    $self->{'alerts'} = 1;
+    $self->{'xdebug'} = 0;
+    $self->{'mxtimeout'} = 60;
+    $self->{'script'} = $script;
+    $self->{'path'} = $ENV{'PATH'};
+    $self->{'commandline'} = $commandline;
       
     # Initialize variables - these are defaults
 
-    $self->{mqserver} = defined($ENV{'XAS_MQSERVER'}) 
+    $self->{'mqserver'} = defined($ENV{'XAS_MQSERVER'}) 
         ? $ENV{'XAS_MQSERVER'} 
         : 'localhost';
 
-    $self->{mqport} = defined($ENV{'XAS_MQPORT'}) 
+    $self->{'mqport'} = defined($ENV{'XAS_MQPORT'}) 
         ? $ENV{'XAS_MQPORT'} 
         : '61613';
 
-    $self->{mqlevel} = defined ($ENV{'XAS_MQLEVEL'})
+    $self->{'mqlevel'} = defined ($ENV{'XAS_MQLEVEL'})
         ? $ENV{'XAS_MQLEVEL'}
         : '1.0';
 
-    $self->{mxserver} = defined($ENV{'XAS_MXSERVER'}) 
+    $self->{'mxserver'} = defined($ENV{'XAS_MXSERVER'}) 
         ? $ENV{'XAS_MXSERVER'} 
         : 'localhost';
 
-    $self->{mxport} = defined($ENV{'XAS_MXPORT'}) 
+    $self->{'mxport'} = defined($ENV{'XAS_MXPORT'}) 
         ? $ENV{'XAS_MXPORT'} 
         : '25';
 
-    $self->{domain} = defined($ENV{'XAS_DOMAIN'}) 
+    $self->{'domain'} = defined($ENV{'XAS_DOMAIN'}) 
         ? $ENV{'XAS_DOMAIN'} 
         : hostdomain();
 
-    $self->{msgs} = defined($ENV{'XAS_MSGS'}) 
+    $self->{'msgs'} = defined($ENV{'XAS_MSGS'}) 
         ? qr/$ENV{'XAS_MSGS'}/i 
         : qr/.*\.msg$/i;
 
+    $self->{'throws'} = defined($ENV{'XAS_ERR_THROWS'}) 
+        ? $ENV{'XAS_ERR_THROWS'} 
+        : 'xas';
+
+    $self->{'priority'} = defined($ENV{'XAS_ERR_PRIORITY'}) 
+        ? $ENV{'XAS_ERR_PRIORITY'} 
+        : 'low';
+
+    $self->{'facility'} = defined($ENV{'XAS_ERR_FACILITY'}) 
+        ? $ENV{'XAS_ERR_FACILITY'} 
+        : 'systems';
 
     # platform specific
 
@@ -183,113 +242,123 @@ sub init {
 
         require Win32;
 
-        $self->{host} = defined($ENV{'XAS_HOSTNAME'}) 
+        $self->{'host'} = defined($ENV{'XAS_HOSTNAME'}) 
             ? $ENV{'XAS_HOSTNAME'} 
             : Win32::NodeName();
 
-        $self->{root} = Dir(defined($ENV{'XAS_ROOT'}) 
+        $self->{'root'} = Dir(defined($ENV{'XAS_ROOT'}) 
             ? $ENV{'XAS_ROOT'} 
             : ['C:', 'XAS']);
 
-        $self->{etc} = Dir(defined($ENV{'XAS_ETC'})   
+        $self->{'etc'} = Dir(defined($ENV{'XAS_ETC'})   
             ? $ENV{'XAS_ETC'}   
             : [$self->{root}, 'etc']);
 
-        $self->{tmp} = Dir(defined($ENV{'XAS_TMP'})   
+        $self->{'tmp'} = Dir(defined($ENV{'XAS_TMP'})   
             ? $ENV{'XAS_TMP'}   
             : [$self->{root}, 'tmp']);
 
-        $self->{var} = Dir(defined($ENV{'XAS_VAR'})   
+        $self->{'var'} = Dir(defined($ENV{'XAS_VAR'})   
             ? $ENV{'XAS_VAR'}   
             : [$self->{root}, 'var']);
 
-        $self->{lib} = Dir(defined($ENV{'XAS_LIB'})   
+        $self->{'lib'} = Dir(defined($ENV{'XAS_LIB'})   
             ? $ENV{'XAS_LIB'}   
             : [$self->{root}, 'var', 'lib']);
 
-        $self->{log} = Dir(defined($ENV{'XAS_LOG'})   
+        $self->{'log'} = Dir(defined($ENV{'XAS_LOG'})   
             ? $ENV{'XAS_LOG'}   
             : [$self->{root}, 'var', 'log']);
 
-        $self->{run} = Dir(defined($ENV{'XAS_RUN'})   
+        $self->{'locks'} = Dir(defined($ENV{'XAS_LOCKS'})   
+            ? $ENV{'XAS_LOCKS'}   
+            : [$self->{root}, 'var', 'lock']);
+
+        $self->{'run'} = Dir(defined($ENV{'XAS_RUN'})   
             ? $ENV{'XAS_RUN'}   
             : [$self->{root}, 'var', 'run']);
 
-        $self->{spool} = Dir(defined($ENV{'XAS_SPOOL'}) 
+        $self->{'spool'} = Dir(defined($ENV{'XAS_SPOOL'}) 
             ? $ENV{'XAS_SPOOL'} 
             : [$self->{root}, 'var', 'spool']);
 
-        $self->{mxmailer}  = defined($ENV{'XAS_MXMAILER'}) 
+        $self->{'mxmailer'}  = defined($ENV{'XAS_MXMAILER'}) 
             ? $ENV{'XAS_MXMAILER'} 
             : 'smtp';
 
-        $self->{username} = Win32::LoginName();
+        $self->{'username'} = Win32::LoginName();
 
     } else {
 
         # this assumes a unix like working environment
 
-        $self->{host} = defined($ENV{'XAS_HOSTNAME'}) 
+        $self->{'host'} = defined($ENV{'XAS_HOSTNAME'}) 
             ? $ENV{'XAS_HOSTNAME'} 
             : `hostname -s`;
 
-        chomp($self->{host});
+        chomp($self->{'host'});
 
-        $self->{root} = Dir(defined($ENV{'XAS_ROOT'}) 
+        $self->{'root'} = Dir(defined($ENV{'XAS_ROOT'}) 
             ? $ENV{'XAS_ROOT'} 
             : ['/']);
 
-        $self->{etc} = Dir(defined($ENV{'XAS_ETC'})   
+        $self->{'etc'} = Dir(defined($ENV{'XAS_ETC'})   
             ? $ENV{'XAS_ETC'}   
             : [$self->{root}, 'etc', 'xas']);
 
-        $self->{tmp} = Dir(defined($ENV{'XAS_TMP'})   
+        $self->{'tmp'} = Dir(defined($ENV{'XAS_TMP'})   
             ? $ENV{'XAS_TMP'} 
             : ['/', 'tmp']);
 
-        $self->{var} = Dir(defined($ENV{'XAS_VAR'})   
+        $self->{'var'} = Dir(defined($ENV{'XAS_VAR'})   
             ? $ENV{'XAS_VAR'}   
             : [$self->{root}, 'var']);
 
-        $self->{lib} = Dir(defined($ENV{'XAS_LIB'})   
+        $self->{'lib'} = Dir(defined($ENV{'XAS_LIB'})   
             ? $ENV{'XAS_LIB'}   
             : [$self->{root}, 'var', 'lib', 'xas']);
 
-        $self->{log} = Dir(defined($ENV{'XAS_LOG'})   
+        $self->{'log'} = Dir(defined($ENV{'XAS_LOG'})   
             ? $ENV{'XAS_LOG'}   
             : [$self->{root}, 'var', 'log', 'xas']);
 
-        $self->{run} = Dir(defined($ENV{'XAS_RUN'})   
+        $self->{'locks'} = Dir(defined($ENV{'XAS_LOCKS'})   
+            ? $ENV{'XAS_LOCKS'}   
+            : [$self->{root}, 'var', 'lock', 'xas']);
+
+        $self->{'run'} = Dir(defined($ENV{'XAS_RUN'})   
             ? $ENV{'XAS_RUN'}   
             : [$self->{root}, 'var', 'run', 'xas']);
 
-        $self->{spool} = Dir(defined($ENV{'XAS_SPOOL'}) 
+        $self->{'spool'} = Dir(defined($ENV{'XAS_SPOOL'}) 
             ? $ENV{'XAS_SPOOL'} 
             : [$self->{root}, 'var', 'spool', 'xas']);
 
-        $self->{mxmailer}  = defined($ENV{'XAS_MXMAILER'}) 
+        $self->{'mxmailer'}  = defined($ENV{'XAS_MXMAILER'}) 
           ? $ENV{'XAS_MXMAILER'} 
           : 'sendmail';
 
-        $self->{username} = getpwuid($<);
+        $self->{'username'} = getpwuid($<);
 
     }
 
     # build some common paths
 
-    $self->{sbin} = Dir(defined($ENV{'XAS_SBIN'})  
+    $self->{'sbin'} = Dir(defined($ENV{'XAS_SBIN'})  
         ? $ENV{'XAS_SBIN'}  
-        : [$self->{root}, 'sbin']);
+        : [$self->{'root'}, 'sbin']);
 
-    $self->{bin} = Dir(defined($ENV{'XAS_BIN'})   
+    $self->{'bin'} = Dir(defined($ENV{'XAS_BIN'})   
         ? $ENV{'XAS_BIN'}   
-        : [$self->{root}, 'bin']);
+        : [$self->{'root'}, 'bin']);
 
-    $self->{log_type} = defined($ENV{'XAS_LOG_TYPE'})
+    # define some logging options
+
+    $self->{'log_type'} = defined($ENV{'XAS_LOG_TYPE'})
         ? $ENV{'XAS_LOG_TYPE'}
         : 'console';
 
-    $self->{log_facility} = defined($ENV{'XAS_LOG_FACILITY'})
+    $self->{'log_facility'} = defined($ENV{'XAS_LOG_FACILITY'})
         ? $ENV{'XAS_LOG_FACILITY'}
         : 'local6';
 
@@ -297,17 +366,17 @@ sub init {
 
     ($name, $path, $suffix) = fileparse($0, qr{\..*});
 
-    $self->{logfile} = File($self->{log}, $name . '.log');
-    $self->{pidfile} = File($self->{run}, $name . '.pid');
-    $self->{cfgfile} = File($self->{etc}, $name . '.ini');
+    $self->{'log_file'} = File($self->{'log'}, $name . '.log');
+    $self->{'pid_file'} = File($self->{'run'}, $name . '.pid');
+    $self->{'cfg_file'} = File($self->{'etc'}, $name . '.ini');
 
     # build some methods, saves typing
 
-    for my $datum (qw( logfile pidfile cfgfile )) {
+    for my $datum (qw( log_file pid_file cfg_file )) {
 
-        $self->class->method($datum => sub {
+        $self->class->methods($datum => sub {
             my $self = shift;
-            my ($p) = $self->validate_params(\@_, [
+            my ($p) = validate_params(\@_, [
                     {optional => 1, default => undef, isa => 'Badger::Filesystem::File' }
                 ],
                 "xas.lib.modules.environment.$datum"
@@ -321,11 +390,11 @@ sub init {
 
     }
 
-    for my $datum (qw( root etc sbin tmp var bin lib log run spool )) {
+    for my $datum (qw( root etc sbin tmp var bin lib log locks run spool )) {
 
-        $self->class->method($datum => sub {
+        $self->class->methods($datum => sub {
             my $self = shift;
-            my ($p) = $self->validate_params(\@_, [
+            my ($p) = validate_params(\@_, [
                     {optional => 1, default => undef, isa => 'Badger::Filesystem::Directory'}
                 ],
                 "xas.lib.modules.environment.$datum"
@@ -338,9 +407,9 @@ sub init {
         });
 
     }
-    
+
     $self->_load_msgs();
-      
+
     return $self;
 
 }
@@ -362,8 +431,8 @@ Your program can use this module in the following fashion:
    base    => 'XAS::Base',
  ;
 
-  $pidfile = $self->env->pidfile;
-  $logfile = $self->env->logfile;
+  $pidfile = $self->env->pid_file;
+  $logfile = $self->env->log_file;
 
   printf("The XAS root is %s\n", $self->env->root);
 
@@ -384,13 +453,18 @@ using the following variables:
 =item B<XAS_ROOT>
 
 The root of the directory structure. On Unix like boxes this will be 
-/usr/local and Windows this will be C:\xas.
+/ and Windows this will be C:\XAS.
 
 =item B<XAS_LOG>
 
 The path for log files. On Unix like boxes this will be /var/log/xas and on
 Windows this will be %XAS_ROOT%\var\log.
 
+=item B<XAS_LOCKS>
+
+The path for lock files. On Unix like boxes this will be /var/lock/xas and on
+Windows this will be %XAS_ROOT%\var\lock.
+
 =item B<XAS_RUN>
 
 The path for pid files. On Unix like boxes this will be /var/run/xas and
@@ -399,7 +473,7 @@ on Windows this will be %XAS_ROOT%\var\run.
 =item B<XAS_SPOOL>
 
 The base path for spool files. On Unix like boxes this will be /var/spool/xas 
-and on Windows this will be %XRS_ROOT%\var\spool.
+and on Windows this will be %XAS_ROOT%\var\spool.
 
 =item B<XAS_LIB>
 
@@ -469,7 +543,19 @@ conventions.
 =item B<XAS_LOG_TYPE>
 
 The log type. This can be "console", "file", "json" or "syslog". Defaults
-to "console">
+to "console"
+
+=item B<XAS_ERR_THROWS>
+
+The default error message type. Defaults to 'xas'.
+
+=item B<XAS_ERR_PRIORITY>
+
+The error message priority type. Defaults to "low".
+
+=item B<XAS_ERR_FACILITY>
+
+The error message facility type. Defaults to "systems".
 
 =back
 
@@ -505,7 +591,7 @@ Example
     $facility = $xas->log_facility;
     $xas->log_facility('local6');
 
-=head2 logfile
+=head2 log_file
 
 This method will return a pre-generated name for a log file. The name will be 
 based on the programs name with a ".log" extension, along with the path to
@@ -514,10 +600,10 @@ file name.
 
 Example
 
-    $logfile = $xas->logfile;
-    $xas->logfile("/some/path/mylogfile.log");
+    $logfile = $xas->log_file;
+    $xas->log_file("/some/path/mylogfile.log");
 
-=head2 pidfile
+=head2 pid_file
 
 This method will return a pre-generated name for a pid file. The name will be 
 based on the programs name with a ".pid" extension, along with the path to
@@ -526,10 +612,10 @@ file name.
 
 Example
 
-    $pidfile = $xas->pidfile;
-    $xas->pidfile("/some/path/myfile.pid");
+    $pidfile = $xas->pid_file;
+    $xas->pid_file("/some/path/myfile.pid");
 
-=head2 cfgfile
+=head2 cfg_file
 
 This method will return a pre-generated name for a configuration file. The 
 name will be based on the programs name with a ".ini" extension, along with 
@@ -538,8 +624,8 @@ self generated configuration file name.
 
 Example
 
-    $inifile = $xas->cfgfile;
-    $xas->cfgfile("/some/path/myfile.cfg");
+    $inifile = $xas->cfg_file;
+    $xas->cfg_file("/some/path/myfile.cfg");
 
 =head2 mqserver
 
